C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE rjfpkvalj (crec, jval, idbg, ierr)

C @(#)Subroutine: rjfpkvalj          Author: R.A. Jansen -- Jul 12, 2009
C @(#)
C @(#)  Purpose:  Write an integer-valued keyword value to a FITS header
C @(#)    record 'crec' for a keyword value 'jval' that is declared as a
C @(#)    variable of INTEGER*4 (32-bit integer) data type. Depending on
C @(#)    host OS and compiler, this routine and 'rjfpkvali' may produce
C @(#)    identical results.   The keyword value will be written  right-
C @(#)    justified on byte 30 in the header record.  If verbosity level
C @(#)    'idbg' > 0, additional messages may be printed.   Error status
C @(#)    'ierr' will be non-zero on exit, should any error condition be
C @(#)    detected.   Its value (if >2000)  uniquely identifies  a known
C @(#)    error condition.
C @(#)
C @(#)  Calling sequence:
C @(#)    CALL rjfpkvalj(crec, jval, idbg, ierr), where 'crec' is a char
C @(#)    string with a declared length of 80 characters and 'jval' is a
C @(#)    integer of the INTEGER*4 data type. 'idbg' and 'ierr' are both
C @(#)    integers of the default INTEGER data type.
C @(#)
C @(#)  Note:  this task is meant to write an integer keyword value to a
C @(#)    header record that has been initialized with the FITS keyword;
C @(#)    use one of 'rjfmkval?' to modify an existing keyword value.
C @(#)
C @(#)  Dependencies:	clen, cinit
C @(#)
C @(#)  Revision history:
C @(#)    Jul 12, 2009 [RAJ] -- Initial version of this routine.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	crec*80
      INTEGER*4 jval
      INTEGER	idbg, ierr

C --- Declaration of local variables...
      CHARACTER dbid*19, cval*80, cc
      INTEGER*4 jtmp
      INTEGER	clen, ic, i

C     'i0','i9','ib','ip' and 'im' are shorthand integer equivalents in
C     the ASCII collating sequence of digits 0 and 9, space, + and - ,
C     respectively...
      INTEGER	i0, i9, ib, ip, im

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfpkvalj): '

C --- Initialize local variables...
      CALL cinit(cval)
      i0 = ICHAR('0')
      i9 = ICHAR('9')
      ib = ICHAR(' ')
      ip = ICHAR('+')
      im = ICHAR('-')

C --- Try to write the integer keyword value to character string 'cval',
C     right-justified on character 30...
      WRITE(cval,'(I30)') jval

C --- Test that the resulting string has only blanks in characters 1--10
C     and only digits or blanks in characters 11--30 ...
      DO i=1,30
         cc = cval(i:i)
         ic = ICHAR(cc)
         IF (i.LE.10) THEN
            IF (ic.NE.ib) THEN
C              Write has failed or INTEGER defaults to INTEGER*{>8}...
               IF (idbg.GT.0) WRITE(*,*) dbid//
     +            'failed to write INTEGER*4 keyword value to record.'
               ierr = 2361
               GOTO 9
            ENDIF
         ELSE
            IF (ic.NE.ib.AND.ic.NE.im.AND.(ic.LT.i0.OR.ic.GT.i9)) THEN
C              Write appears to have failed (likely ***, or some such)..
               IF (idbg.GT.0) WRITE(*,*) dbid//
     +            'failed to write INTEGER*4 keyword value to record.'
               ierr = 2362
               GOTO 9
            ENDIF
         ENDIF
      ENDDO
      cval(31:31) = ' '

C --- Try to read back the value written and compare with the original..
      READ(cval,*,IOSTAT=ierr) jtmp
      IF (ierr.NE.0) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      'failed to read back INTEGER*4 keyword value from record.'
         ierr = 2363
         GOTO 9
      ENDIF
      IF (jtmp.NE.jval) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//'keyword value '//
     +      'read back from record does not match input value.'
         ierr = 2364
         GOTO 9
      ENDIF


C --- We appear to have successfully written the integer keyword value,
C     so copy characters 11 through 30 to the output header record...
      crec(11:30) = cval(11:30)


9     IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


