C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

      SUBROUTINE rjfpkvall (crec, lval, idbg, ierr)

C @(#)Subroutine: rjfpkvall          Author: R.A. Jansen -- Aug 19, 2009
C @(#)
C @(#)  Purpose:  Write a boolean-valued keyword value  to a FITS header
C @(#)    record 'crec' for a keyword value 'lval' that is declared as a
C @(#)    variable of the LOGICAL data type.   The keyword value will be
C @(#)    written as a single capital letter "T" or "F", right-justified
C @(#)    on byte 30 in the header record.  If verbosity level 'idbg'>0,
C @(#)    additional messages may be printed.   Error status 'ierr' will
C @(#)    be non-zero on exit, if any error is detected.  Its value  (if
C @(#)    >2000) uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence:
C @(#)    CALL rjfpkvall(crec, lval, idbg, ierr), where 'crec' is a char
C @(#)    string with a declared length of 80 characters and 'lval' is a
C @(#)    boolean of the LOGICAL data type.   'idbg' and 'ierr' are both
C @(#)    integers.
C @(#)
C @(#)  Note:  this task is meant to write a boolean keyword value  to a
C @(#)    header record that has been initialized with the FITS keyword;
C @(#)    use one of 'rjfmkval?' to modify an existing keyword value.
C @(#)
C @(#)  Dependencies:	clen, cinit
C @(#)
C @(#)  Revision history:
C @(#)    Aug 19, 2009 [RAJ] -- Initial version of this routine.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	crec*80
      INTEGER	idbg, ierr
      LOGICAL	lval

C --- Declaration of local variables...
      CHARACTER dbid*19, cval*80, cc
      INTEGER	clen, ic, j
      LOGICAL	ltmp

C     'ib', 'iFF', and 'iTT' are shorthand integer equivalents in the
C     ASCII collating sequence of the space, F and T, respectively...
      INTEGER	ib, iFF, iTT

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C --- Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfpkvall): '

C --- Initialize local variables...
      CALL cinit(cval)
      ib  = ICHAR(' ')
      iFF = ICHAR('F')
      iTT = ICHAR('T')

C --- Try to write the boolean keyword value to character string 'cval',
C     right-justified on character 30...
      IF (lval) THEN
         WRITE(cval,'(A30)') CHAR(iTT)
      ELSE
         WRITE(cval,'(A30)') CHAR(iFF)
      ENDIF

C --- Test that the resulting string has only blanks in characters 1--29
C     and only T or F in character 30 ...
      DO j=1,29
         cc = cval(j:j)
         ic = ICHAR(cc)
         IF (ic.NE.ib) THEN
C           Write has failed for unknown reasons...
            IF (idbg.GT.0) WRITE(*,*)
     +         dbid//' failed to write LOGICAL keyword value to record.'
            ierr = 2421
            GOTO 9
         ENDIF
      ENDDO
      cc = cval(30:30)
      ic = ICHAR(cc)
      IF (ic.NE.iFF.AND.ic.NE.iTT) THEN
C        Write appears to have failed (likely *, or some such)...
         IF (idbg.GT.0) WRITE(*,*)
     +      dbid//' failed to write LOGICAL keyword value to record.'
         ierr = 2422
         GOTO 9
      ENDIF
      cval(31:31) = ' '

C --- Try to read back the value written and compare with the original..
      READ(cval,*,IOSTAT=ierr) ltmp
      IF (ierr.NE.0) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//
     +      ' failed to read back LOGICAL keyword value from record.'
         ierr = 2423
         GOTO 9
      ENDIF
      IF (ltmp.NEQV.lval) THEN
         IF (idbg.GT.0) WRITE(*,*) dbid//' keyword value '//
     +      'read back from record does not match input value.'
         ierr = 2424
         GOTO 9
      ENDIF


C --- We appear to have successfully written the logical keyword value,
C     so copy characters 11 through 30 to the output header record...
      crec(11:30) = cval(11:30)


9     IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


